@@ -5,7 +5,7 @@
 Utilities for mathematical operations.
 """
 #
-#  Copyright © 2014-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2014-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -85,13 +85,12 @@ from operator import eq, ge, gt, le, lt, ne
 from typing import Any, Iterator, List, Optional, Sequence, Union, overload
 
 # 3rd party
-import numpy  # type: ignore
+import numpy
 import pandas  # type: ignore
 from domdf_python_tools.doctools import prettify_docstrings
 from domdf_python_tools.typing import PathLike
-from pandas import DataFrame
 
-pandas.DataFrame.__module__ = "Pandas"
+pandas.DataFrame.__module__ = "pandas"
 
 __all__ = [
 		"intdiv",
@@ -197,8 +196,8 @@ def remove_zero(inputlist: Sequence[Union[float, bool, None]]) -> List[float]:
 	:param inputlist: list to remove zero values from
 	"""
 
-	inputlist = numpy.array(inputlist)
-	return list(inputlist[numpy.nonzero(inputlist)])
+	array = numpy.array(inputlist)
+	return list(array[numpy.nonzero(array)])
 
 
 def isint(num: float) -> bool:
@@ -208,8 +207,6 @@ def isint(num: float) -> bool:
 	.. note:: This function only works with floating-point numbers
 
 	:param num: value to check
-
-	:rtype: bool
 	"""
 
 	return num == int(num)
@@ -220,8 +217,6 @@ def represents_int(s: Any) -> bool:
 	Checks whether a value can be converted to an :class:`int`.
 
 	:param s: value to check
-
-	:rtype: bool
 	"""
 
 	try:
@@ -271,9 +266,9 @@ def strip_booleans(ls: Sequence[Any]) -> List:
 
 def strip_nonetype(ls: Sequence[Any]) -> List:
 	"""
-	Remove None from a list.
+	Remove :py:obj:`None` from a list.
 
-	:param ls: the list to remove None from.
+	:param ls: the list to remove :py:obj:`None` from.
 
 	:return: The list without :py:obj:`None` values.
 	"""
@@ -321,7 +316,7 @@ def nanrsd(ls: Sequence[Any], dtype=float) -> float:
 	return float(std / abs(mean))
 
 
-def strip_none_bool_string(ls: Sequence[Any]) -> List:
+def strip_none_bool_string(ls: Sequence) -> List:
 	"""
 	Remove :py:obj:`None`, boolean and string values from a list.
 
@@ -331,6 +326,7 @@ def strip_none_bool_string(ls: Sequence[Any]) -> List:
 	ls = strip_nonetype(ls)
 	ls = strip_booleans(ls)
 	ls = strip_strings(ls)
+
 	return ls
 
 
@@ -416,7 +412,7 @@ def mod_inverse(a: int, m: int) -> Optional[float]:
 
 	:param a:
 	:param m:
-	"""  # noqa D400
+	"""  # noqa: D400
 
 	if gcd(a, m) != 1:
 		return None  # No mod inverse exists if a & m aren't relatively prime
@@ -441,12 +437,13 @@ _precalc_fact = numpy.log([math.factorial(n) for n in range(20)])
 
 def log_factorial(x: float) -> float:
 	"""
+	Returns the natural logarithm of ``x`` factorial (``ln(x!``).
 
 	:param x:
 	"""
 
 	arr = numpy.array(x)
-	m: bool = (arr >= _precalc_fact.size)
+	m: bool = (arr >= _precalc_fact.size)  # type: ignore
 	out = numpy.empty(arr.shape)
 
 	out[~m] = _precalc_fact[arr[~m].astype(int)]
@@ -504,12 +501,10 @@ class FRange(Sequence[float]):
 			super().__delattr__(key)
 
 	@overload
-	def __init__(self, stop: float) -> None:
-		...  # pragma: no cover
+	def __init__(self, stop: float) -> None: ...
 
 	@overload
-	def __init__(self, start: float, stop: float, step: float = ...) -> None:
-		...  # pragma: no cover
+	def __init__(self, start: float, stop: float, step: float = ...) -> None: ...
 
 	def __init__(self, start=None, stop=None, step=1.0) -> None:  # type: ignore
 		if start is not None and stop is None:
@@ -607,12 +602,10 @@ class FRange(Sequence[float]):
 			count += 1
 
 	@overload
-	def __getitem__(self, i: int) -> int:
-		...
+	def __getitem__(self, i: int) -> int: ...
 
 	@overload
-	def __getitem__(self, s: slice) -> "FRange":
-		...
+	def __getitem__(self, s: slice) -> "FRange": ...
 
 	def __getitem__(self, item):
 		"""
@@ -735,14 +728,14 @@ class FRange(Sequence[float]):
 		return hash(tuple(self))
 
 
-def concatenate_csv(*files: PathLike, outfile: Optional[PathLike] = None) -> DataFrame:
+def concatenate_csv(*files: PathLike, outfile: Optional[PathLike] = None) -> pandas.DataFrame:
 	r"""
 	Concatenate multiple CSV files together and return a :class:`pandas.DataFrame` representing the output.
 
 	:param \*files: The files to concatenate.
 	:param outfile: The file to save the output as. If :py:obj:`None` no file will be saved.
 
-	:return: A :class:`pandas.DataFrame` containing the concatenated CSV data
+	:return: A :class:`pandas.DataFrame` containing the concatenated CSV data.
 
 	.. versionadded:: 0.3.0
 	"""
